==> xapiwrapper-1.10.1.tgz: package/src/verbs.js <==
(function(ADL){
   ADL.verbs = {
      "abandoned" : {
         "id" : "https://w3id.org/xapi/adl/verbs/abandoned",
         "display" : {"en-US" : "abandoned"}
      },
      "answered" : {
         "id" : "http://adlnet.gov/expapi/verbs/answered",
         "display" : {"de-DE" : "beantwortete",
                      "en-US" : "answered",
                      "fr-FR" : "a répondu",
                      "es-ES" : "contestó"}
      },
      "asked" : {
         "id" : "http://adlnet.gov/expapi/verbs/asked",
         "display" : {"de-DE" : "fragte",
                      "en-US" : "asked",
                      "fr-FR" : "a demandé",
                      "es-ES" : "preguntó"}
      },
      "attempted" : {
         "id" : "http://adlnet.gov/expapi/verbs/attempted",
         "display" : {"de-DE" : "versuchte",
                      "en-US" : "attempted",
                      "fr-FR" : "a essayé",
                      "es-ES" : "intentó"}
      },
      "attended" : {
         "id" : "http://adlnet.gov/expapi/verbs/attended",
         "display" : {"de-DE" : "nahm teil an",
                      "en-US" : "attended",
                      "fr-FR" : "a suivi",
                      "es-ES" : "asistió"}
      },
      "commented" : {
         "id" : "http://adlnet.gov/expapi/verbs/commented",
         "display" : {"de-DE" : "kommentierte",
                      "en-US" : "commented",
                      "fr-FR" : "a commenté",
                      "es-ES" : "comentó"}
      },
      "completed" : {
         "id" : "http://adlnet.gov/expapi/verbs/completed",
         "display" : {"de-DE" : "beendete",
                      "en-US" : "completed",
                      "fr-FR" : "a terminé",
                      "es-ES" : "completó"}
      },
      "exited" : {
         "id" : "http://adlnet.gov/expapi/verbs/exited",
         "display" : {"de-DE" : "verließ",
                      "en-US" : "exited",
                      "fr-FR" : "a quitté",
                      "es-ES" : "salió"}
      },
      "experienced" : {
         "id" : "http://adlnet.gov/expapi/verbs/experienced",
         "display" : {"de-DE" : "erlebte",
                      "en-US" : "experienced",
                      "fr-FR" : "a éprouvé",
                      "es-ES" : "experimentó"}
      },
      "failed" : {
         "id" : "http://adlnet.gov/expapi/verbs/failed",
         "display" : {"de-DE" : "verfehlte",
                      "en-US" : "failed",
                      "fr-FR" : "a échoué",
                      "es-ES" : "fracasó"}
      },
      "imported" : {
         "id" : "http://adlnet.gov/expapi/verbs/imported",
         "display" : {"de-DE" : "importierte",
                      "en-US" : "imported",
                      "fr-FR" : "a importé",
                      "es-ES" : "importó"}
      },
      "initialized" : {
         "id" : "http://adlnet.gov/expapi/verbs/initialized",
         "display" : {"de-DE" : "initialisierte",
                      "en-US" : "initialized",
                      "fr-FR" : "a initialisé",
                      "es-ES" : "inicializó"}
      },
      "interacted" : {
         "id" : "http://adlnet.gov/expapi/verbs/interacted",
         "display" : {"de-DE" : "interagierte",
                      "en-US" : "interacted",
                      "fr-FR" : "a interagi",
                      "es-ES" : "interactuó"}
      },
      "launched" : {
         "id" : "http://adlnet.gov/expapi/verbs/launched",
         "display" : {"de-DE" : "startete",
                      "en-US" : "launched",
                      "fr-FR" : "a lancé",
                      "es-ES" : "lanzó"}
      },
      "mastered" : {
         "id" : "http://adlnet.gov/expapi/verbs/mastered",
         "display" : {"de-DE" : "meisterte",
                      "en-US" : "mastered",
                      "fr-FR" : "a maîtrisé",
                      "es-ES" : "dominó"}
      },
      "passed" : {
         "id" : "http://adlnet.gov/expapi/verbs/passed",
         "display" : {"de-DE" : "bestand",
                      "en-US" : "passed",
                      "fr-FR" : "a réussi",
                      "es-ES" : "aprobó"}
      },
      "preferred" : {
         "id" : "http://adlnet.gov/expapi/verbs/preferred",
         "display" : {"de-DE" : "bevorzugte",
                      "en-US" : "preferred",
                      "fr-FR" : "a préféré",
                      "es-ES" : "prefirió"}
      },
      "progressed" : {
         "id" : "http://adlnet.gov/expapi/verbs/progressed",
         "display" : {"de-DE" : "machte Fortschritt mit",
                      "en-US" : "progressed",
                      "fr-FR" : "a progressé",
                      "es-ES" : "progresó"}
      },
      "registered" : {
         "id" : "http://adlnet.gov/expapi/verbs/registered",
         "display" : {"de-DE" : "registrierte",
                      "en-US" : "registered",
                      "fr-FR" : "a enregistré",
                      "es-ES" : "registró"}
      },
      "responded" : {
         "id" : "http://adlnet.gov/expapi/verbs/responded",
         "display" : {"de-DE" : "reagierte",
                      "en-US" : "responded",
                      "fr-FR" : "a répondu",
                      "es-ES" : "respondió"}
      },
      "resumed" : {
         "id" : "http://adlnet.gov/expapi/verbs/resumed",
         "display" : {"de-DE" : "setzte fort",
                      "en-US" : "resumed",
                      "fr-FR" : "a repris",
                      "es-ES" : "continuó"}
      },
      "satisfied" : {
         "id" : "https://w3id.org/xapi/adl/verbs/satisfied",
         "display" : {"en-US" : "satisfied"}
      },
      "scored" : {
         "id" : "http://adlnet.gov/expapi/verbs/scored",
         "display" : {"de-DE" : "erreichte",
                      "en-US" : "scored",
                      "fr-FR" : "a marqué",
                      "es-ES" : "anotó"}
      },
      "shared" : {
         "id" : "http://adlnet.gov/expapi/verbs/shared",
         "display" : {"de-DE" : "teilte",
                      "en-US" : "shared",
                      "fr-FR" : "a partagé",
                      "es-ES" : "compartió"}
      },
      "suspended" : {
         "id" : "http://adlnet.gov/expapi/verbs/suspended",
         "display" : {"de-DE" : "pausierte",
                      "en-US" : "suspended",
                      "fr-FR" : "a suspendu",
                      "es-ES" : "aplazó"}
      },
      "terminated" : {
         "id" : "http://adlnet.gov/expapi/verbs/terminated",
         "display" : {"de-DE" : "beendete",
                      "en-US" : "terminated",
                      "fr-FR" : "a terminé",
                      "es-ES" : "terminó"}
      },
      "voided" : {
         "id" : "http://adlnet.gov/expapi/verbs/voided",
         "display" : {"de-DE" : "entwertete",
                      "en-US" : "voided",
                      "fr-FR" : "a annulé",
                      "es-ES" : "anuló"}
      },
      "waived" : {
         "id" : "https://w3id.org/xapi/adl/verbs/waived",
         "display" : {"en-US" : "waived"}
      }
   };
}(window.ADL = window.ADL || {}));

==> xapiwrapper-1.11.0.tgz: package/src/verbs.js <==
(function(ADL){
   ADL.verbs = {
      "abandoned" : {
         "id" : "https://w3id.org/xapi/adl/verbs/abandoned",
         "display" : {"en-US" : "abandoned"}
      },
      "answered" : {
         "id" : "http://adlnet.gov/expapi/verbs/answered",
         "display" : {"de-DE" : "beantwortete",
                      "en-US" : "answered",
                      "fr-FR" : "a répondu",
                      "es-ES" : "contestó",
                      "ar-AR" : "أجاب"}
      },
      "asked" : {
         "id" : "http://adlnet.gov/expapi/verbs/asked",
         "display" : {"de-DE" : "fragte",
                      "en-US" : "asked",
                      "fr-FR" : "a demandé",
                      "es-ES" : "preguntó",
                      "ar-AR" : "طلب"}
      },
      "attempted" : {
         "id" : "http://adlnet.gov/expapi/verbs/attempted",
         "display" : {"de-DE" : "versuchte",
                      "en-US" : "attempted",
                      "fr-FR" : "a essayé",
                      "es-ES" : "intentó",
                      "ar-AR" : "حاول"}
      },
      "attended" : {
         "id" : "http://adlnet.gov/expapi/verbs/attended",
         "display" : {"de-DE" : "nahm teil an",
                      "en-US" : "attended",
                      "fr-FR" : "a suivi",
                      "es-ES" : "asistió",
                      "ar-AR" : "حضر"}
      },
      "commented" : {
         "id" : "http://adlnet.gov/expapi/verbs/commented",
         "display" : {"de-DE" : "kommentierte",
                      "en-US" : "commented",
                      "fr-FR" : "a commenté",
                      "es-ES" : "comentó",
                      "ar-AR" : "علق"}
      },
      "completed" : {
         "id" : "http://adlnet.gov/expapi/verbs/completed",
         "display" : {"de-DE" : "beendete",
                      "en-US" : "completed",
                      "fr-FR" : "a terminé",
                      "es-ES" : "completó",
                      "ar-AR" : "أكمل"}
      },
      "exited" : {
         "id" : "http://adlnet.gov/expapi/verbs/exited",
         "display" : {"de-DE" : "verließ",
                      "en-US" : "exited",
                      "fr-FR" : "a quitté",
                      "es-ES" : "salió",
                      "ar-AR" : "خرج"}
      },
      "experienced" : {
         "id" : "http://adlnet.gov/expapi/verbs/experienced",
         "display" : {"de-DE" : "erlebte",
                      "en-US" : "experienced",
                      "fr-FR" : "a éprouvé",
                      "es-ES" : "experimentó",
                      "ar-AR" : "شاهد"}
      },
      "failed" : {
         "id" : "http://adlnet.gov/expapi/verbs/failed",
         "display" : {"de-DE" : "verfehlte",
                      "en-US" : "failed",
                      "fr-FR" : "a échoué",
                      "es-ES" : "fracasó",
                      "ar-AR" : "فشل"}
      },
      "imported" : {
         "id" : "http://adlnet.gov/expapi/verbs/imported",
         "display" : {"de-DE" : "importierte",
                      "en-US" : "imported",
                      "fr-FR" : "a importé",
                      "es-ES" : "importó",
                      "ar-AR" : "مستورد"}
      },
      "initialized" : {
         "id" : "http://adlnet.gov/expapi/verbs/initialized",
         "display" : {"de-DE" : "initialisierte",
                      "en-US" : "initialized",
                      "fr-FR" : "a initialisé",
                      "es-ES" : "inicializó",
                      "ar-AR" : "بدأ"}
      },
      "interacted" : {
         "id" : "http://adlnet.gov/expapi/verbs/interacted",
         "display" : {"de-DE" : "interagierte",
                      "en-US" : "interacted",
                      "fr-FR" : "a interagi",
                      "es-ES" : "interactuó",
                      "ar-AR" : "تفاعل"}
      },
      "launched" : {
         "id" : "http://adlnet.gov/expapi/verbs/launched",
         "display" : {"de-DE" : "startete",
                      "en-US" : "launched",
                      "fr-FR" : "a lancé",
                      "es-ES" : "lanzó",
                      "ar-AR" : "أطلق"}
      },
      "mastered" : {
         "id" : "http://adlnet.gov/expapi/verbs/mastered",
         "display" : {"de-DE" : "meisterte",
                      "en-US" : "mastered",
                      "fr-FR" : "a maîtrisé",
                      "es-ES" : "dominó",
                      "ar-AR" : "أتقن"}
      },
      "passed" : {
         "id" : "http://adlnet.gov/expapi/verbs/passed",
         "display" : {"de-DE" : "bestand",
                      "en-US" : "passed",
                      "fr-FR" : "a réussi",
                      "es-ES" : "aprobó",
                      "ar-AR" : "نجح"}
      },
      "preferred" : {
         "id" : "http://adlnet.gov/expapi/verbs/preferred",
         "display" : {"de-DE" : "bevorzugte",
                      "en-US" : "preferred",
                      "fr-FR" : "a préféré",
                      "es-ES" : "prefirió",
                      "ar-AR" : "فضل"}
      },
      "progressed" : {
         "id" : "http://adlnet.gov/expapi/verbs/progressed",
         "display" : {"de-DE" : "machte Fortschritt mit",
                      "en-US" : "progressed",
                      "fr-FR" : "a progressé",
                      "es-ES" : "progresó",
                      "ar-AR" : "تقدم"}
      },
      "registered" : {
         "id" : "http://adlnet.gov/expapi/verbs/registered",
         "display" : {"de-DE" : "registrierte",
                      "en-US" : "registered",
                      "fr-FR" : "a enregistré",
                      "es-ES" : "registró",
                      "ar-AR" : "سجل"}
      },
      "responded" : {
         "id" : "http://adlnet.gov/expapi/verbs/responded",
         "display" : {"de-DE" : "reagierte",
                      "en-US" : "responded",
                      "fr-FR" : "a répondu",
                      "es-ES" : "respondió",
                      "ar-AR" : "استجاب"}
      },
      "resumed" : {
         "id" : "http://adlnet.gov/expapi/verbs/resumed",
         "display" : {"de-DE" : "setzte fort",
                      "en-US" : "resumed",
                      "fr-FR" : "a repris",
                      "es-ES" : "continuó",
                      "ar-AR" : "استأنف"}
      },
      "satisfied" : {
         "id" : "https://w3id.org/xapi/adl/verbs/satisfied",
         "display" : {"de-DE" : "befriedigt",
                      "en-US" : "satisfied",
                      "fr-FR" : "satisfaite",
                      "es-ES" : "satisfecho",
                      "ar-AR" : "راض"}
      },
      "scored" : {
         "id" : "http://adlnet.gov/expapi/verbs/scored",
         "display" : {"de-DE" : "erreichte",
                      "en-US" : "scored",
                      "fr-FR" : "a marqué",
                      "es-ES" : "anotó",
                      "ar-AR" : "سحل النقاط"}
      },
      "shared" : {
         "id" : "http://adlnet.gov/expapi/verbs/shared",
         "display" : {"de-DE" : "teilte",
                      "en-US" : "shared",
                      "fr-FR" : "a partagé",
                      "es-ES" : "compartió",
                      "ar-AR" : "شارك"}
      },
      "suspended" : {
         "id" : "http://adlnet.gov/expapi/verbs/suspended",
         "display" : {"de-DE" : "pausierte",
                      "en-US" : "suspended",
                      "fr-FR" : "a suspendu",
                      "es-ES" : "aplazó",
                      "ar-AR" : "علق"}
      },
      "terminated" : {
         "id" : "http://adlnet.gov/expapi/verbs/terminated",
         "display" : {"de-DE" : "beendete",
                      "en-US" : "terminated",
                      "fr-FR" : "a terminé",
                      "es-ES" : "terminó",
                      "ar-AR" : "أنهى"}
      },
      "voided" : {
         "id" : "http://adlnet.gov/expapi/verbs/voided",
         "display" : {"de-DE" : "entwertete",
                      "en-US" : "voided",
                      "fr-FR" : "a annulé",
                      "es-ES" : "anuló",
                      "ar-AR" : "فرغ"}
      },
      "waived" : {
         "id" : "https://w3id.org/xapi/adl/verbs/waived",
         "display" : {"de-DE" : "verzichtet",
                      "en-US" : "waived",
                      "fr-FR" : "renoncé",
                      "es-ES" : "renunciado",
                      "ar-AR" : "تخلى"}
      }
   };
}(window.ADL = window.ADL || {}));
